# pytorch_development_framework

###pytorch 开发框架


####yqn-module
构建module结构
```
yqn-module -n key_attention -o /data-hdd/ProjectCode/DeepLearning/pytorch_development_framework/out
```

####yqn-project
构建Project结构
```
yqn-project -n attorney_parse -i 50010 -o /data-hdd/ProjectCode/DeepLearning/pytorch_development_framework/out
```

####yqn-model
下载配置模型到本地目录
```
yqn-model -e online -F
```
